# Encoding: utf-8
#
# Cookbook Name:: vim-go
# Recipe:: default
#
# Copyright 2015, Mist Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

include_recipe 'apt'
include_recipe "git"
include_recipe "vim" if node[:vim_go][:install_vim]

node.set['go']['version'] = "1.4.2"
node.set['go']['filename'] = "go#{node['go']['version']}.#{node['os']}-#{node['go']['platform']}.tar.gz"
node.set['go']['url'] = "http://golang.org/dl/#{node['go']['filename']}"
include_recipe 'golang'

vim_users = search(:users, "vim:true")

vim_users.each do |user_item|
  user = user_item[:id]
  Chef::Log.info "vim-go::default: Processing user #{user.inspect}"
  home_dir = File.join(File.expand_path("~#{user}"))
  next unless (user_item[:vim] && File.exist?(home_dir))
  Chef::Log.info "vim-go::default: #{user}'s dir ${home_dir.inspect} exists and user_item[:vim] is true"
  directory File.join(home_dir, ".vim") do
    recursive true
    owner user
    group user
    mode '0755'
  end
  
  %w(autoload bundle).each do |dir|
    directory File.join(home_dir, ".vim", dir) do
      recursive true
      owner user
      group user
      mode '0755'
    end
  end

  pathogen_file = File.join(home_dir, ".vim", "autoload", "pathogen.vim")
  remote_file pathogen_file do
    source "https://tpo.pe/pathogen.vim"
    user user
    mode "0744"
    not_if { File.exist?(pathogen_file) }
  end
  
  vim_go_file = File.join(home_dir, ".vim", "bundle", "vim-go")
  git vim_go_file do
    repository "https://github.com/fatih/vim-go.git"
    user user
    not_if { File.exist?(vim_go_file) }
  end

  config_info = node[:vim_go][:vimrc]
  
  if config_info && (not config_info.empty?)
    vimrc_file = File.join(home_dir, ".vimrc")
    file vimrc_file do
      owner user
      mode '0755'
      content config_info
      not_if { File.exist?(vimrc_file) }
    end
  end
  
  if node[:vim_go][:install_go_binaries]
    Chef::Log.info "About to vim +GoInstallBinaries +qall"
    bash "finalize_vim_go" do
      code "vim +GoInstallBinaries +qall"
      cwd home_dir
      user user
    end
  end
end


